<?php
/**
 * Nuovo WordPress Theme
 *
 * Codebean.co
 * www.codebean.co
 */

# After Setup Theme
function codebean_after_setup_theme() {
    # Theme Support
    add_theme_support('widgets');
    add_theme_support('automatic-feed-links');
    add_theme_support('post-thumbnails');
    add_theme_support('featured-image');

    # Let WordPress manage the document title (no hard-coded <title> tag in the document head)
    add_theme_support( 'title-tag' );

    # Post Formats
	add_theme_support('post-formats', array('image', 'gallery', 'video', 'link'));

    # Theme Textdomain
    load_theme_textdomain('nuovowp', GOSEO_THEMEDIR . '/languages');

    # HTML5 Galleries
    add_theme_support( 'html5', array( 'gallery', 'caption' ) );

    # Image Settings
    add_theme_support( 'post-thumbnails' );
    add_image_size('codebean-search-thumbnail', 220, 220, true );
    add_image_size('codebean-blog-large', 1300, 650, true );
    add_image_size('codebean-blog-masonry', 600, 9999, false );
    add_image_size('codebean-blog-list', 540, 350, true );
    add_image_size('codebean-portfolio-grid', 650, 500, true );

    # Register Menus
    register_nav_menus(
        array(
            'main-menu'      => 'Main Menu',
            'mobile-menu'    => 'Mobile Menu',
        )
    );

    # WooCommerce
    add_theme_support( 'woocommerce' );
}

# Base Functionality
function codebean_init() {
    global $theme_version;

    $theme_obj     = wp_get_theme();
    $theme_version = $theme_obj->get( 'Version' );

    if ( is_child_theme() ) {
        $template_dir     = basename( get_theme_file_path() );
        $theme_obj        = wp_get_theme( $template_dir );
        $theme_version    = $theme_obj->get( 'Version' );
    }

    # Styles
    wp_register_style('bootstrap', get_theme_file_uri('assets/css/bootstrap.min.css'), null, null);
    wp_register_style('nuovo-main', get_theme_file_uri('assets/css/nuovo.css'), null, $theme_version);
    wp_register_style('animate-css', get_theme_file_uri('assets/css/animate.css'), null, null);

    wp_register_style('icons-fontawesome', get_theme_file_uri('assets/fonts/font-awesome/css/font-awesome.min.css'), null, null);
    wp_register_style('icons-elegant', get_theme_file_uri('assets/fonts/elegant-icons/style.css'), null, null);
    wp_register_style('icons-themify', get_theme_file_uri('assets/fonts/themify-icons/themify-icons.css'), null, null);

	// Theme stylesheet.
	wp_enqueue_style( 'nuovo-style', get_stylesheet_uri() );

    # Scripts
    wp_register_script('wow', get_theme_file_uri( 'assets/js/wow.min.js'), null, null, true );
    wp_register_script('plugins', get_theme_file_uri('assets/js/vendors.js'), null, $theme_version, true);
	wp_register_script('gmaps', get_theme_file_uri('assets/js/gmaps.min.js'), array('jquery', 'google.map.api'), '', true );
    wp_register_script('goseowp-custom', get_theme_file_uri('assets/js/main.min.js'), null, $theme_version, true);

    // Slick Carousel
    wp_register_script('slick', get_theme_file_uri('assets/js/slick/slick.min.js'), null, null, true);
    wp_register_style('slick', get_theme_file_uri('assets/js/slick/slick.css'), null, null);

    // Owl Carousel 2
    wp_register_script('owl-carousel', get_theme_file_uri('assets/js/owl-carousel/owl.carousel.min.js'), null, null, true);
    wp_register_style('owl-carousel', get_theme_file_uri('assets/js/owl-carousel/owl.carousel.css'), null, null);


}

# Enqueue Scritps and other stuff
function codebean_wp_enqueue_scripts() {
    global $post;

    $cdb_api_key = '';
    if ( class_exists('Redux') ) {
        $cdb_api_key = codebean_option('google_map_api_key');
    }

    # Styles
    $rtl_include = '';
    wp_enqueue_style('wp-mediaelement');
    wp_enqueue_style(array('icons-elegant', 'icons-themify', 'bootstrap', 'nuovo-main', 'style'));

    if ( ! class_exists( 'UberMenu') ) {
        wp_enqueue_style( 'icons-fontawesome' );
    }


    if(is_rtl()) {
        wp_enqueue_style(array('bootstrap-rtl'));
    }

    # Scripts
    wp_enqueue_script('wp-mediaelement');
    wp_enqueue_script(array('jquery', 'bootstrap', 'tweenmax', 'drawSVG', 'plugins'));

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

    $page_transition = '1';
    if ( class_exists( 'Redux' ) ) {
        $page_transition = codebean_option('page_transition', '1');
    }

	$translations = array(
		'countdown_days' => esc_html__('days', 'nuovowp'),
		'countdown_hours' => esc_html__('hr', 'nuovowp'),
		'countdown_mins' => esc_html__('min', 'nuovowp'),
		'countdown_sec' => esc_html__('sc', 'nuovowp'),
    );

	wp_localize_script( 'goseowp-custom', 'goseowp_options', $translations );

    wp_localize_script( 'goseowp-custom', 'themeajax', array(
        'url' => admin_url( 'admin-ajax.php' ),
        'l10n' => array (
            'loading' => esc_html__("Loading ...", 'nuovowp'),
            'nomore' => esc_html__("No More Posts", 'nuovowp'),
        ),
        'settings' => array(
            'page_transition_style_in' => 'fadeIn',
            'page_transition_style_out' => 'fadeOut',
            'page_transition_in_speed' => '1000',
            'page_transition_out_speed' => '800',
            'page_transition' => $page_transition
        ),
    ) );

}

/**
 * ------------------------------------------------------------------------------------------------
 * Enqueue google fonts
 * ------------------------------------------------------------------------------------------------
 */
if( ! function_exists( 'codebean_enqueue_google_fonts' ) ) {
	add_action( 'wp_enqueue_scripts', 'codebean_enqueue_google_fonts', 10000 );

	function codebean_enqueue_google_fonts() {
		$default_google_fonts = 'Rubik:300,300i,400,400i,500,500i,700,700i,900,900i|Poppins:300,400,500,600,700';

		if( ! class_exists('Redux') )
			wp_enqueue_style( 'codebean-google-fonts', codebean_get_fonts_url( $default_google_fonts ), array(), '1.0.0' );
	}
}

/**
 * ------------------------------------------------------------------------------------------------
 * Get google fonts URL
 * ------------------------------------------------------------------------------------------------
 */
if( ! function_exists( 'codebean_get_fonts_url') ) {
	function codebean_get_fonts_url( $fonts ) {
		$font_url = '';

		$font_url = add_query_arg( 'family', urlencode( $fonts ), "//fonts.googleapis.com/css" );

		return $font_url;
	}
}

function codebean_wp_footer() {
    # Custom.js
    wp_enqueue_script('goseowp-custom');

	wp_add_inline_script( 'goseowp-custom', goseowp_settings_js(), 'after' );
}

# Enqueue admin styles
function codebean_enqueue_admin_styles() {

    if ( is_admin() ) {
	    wp_enqueue_style( 'goseowp-admin-style', get_theme_file_uri('/assets/css/theme-admin.css' ));
    }
}

add_action( 'admin_enqueue_scripts', 'codebean_enqueue_admin_styles' );

# GOSEOWP Favicon
function goseowp_favicon() {

	if ( function_exists( 'has_site_icon' ) && has_site_icon() ) return '';

	// Get the favicon.
	$favicon = get_parent_theme_file_uri('assets/images/icons/favicon.png' );

	// Get the custom touch icon.
	$touch_icon = get_parent_theme_file_uri('assets/images/icons/apple-touch-icon.png' );

	if ( class_exists('Redux') ) {

		$fav_uploaded = codebean_option('favicon');
		if(isset($fav_uploaded['url']) && $fav_uploaded['url'] != '') {
			$favicon = $fav_uploaded['url'];
		}

		$fav_uploaded_retina = codebean_option( 'favicon_retina' );
		if(isset($fav_uploaded_retina['url']) && $fav_uploaded_retina['url'] != '') {
			$touch_icon = $fav_uploaded_retina['url'];
		}

    }

	?>
        <link rel="shortcut icon" href="<?php echo esc_url($favicon); ?>">
        <link rel="apple-touch-icon-precomposed" sizes="152x152" href="<?php echo esc_url($touch_icon); ?>">
    <?php
}

add_action( 'wp_head', 'goseowp_favicon' );


# Widgets Init
function codebean_widgets_init() {

    # Blog Sidebar
    $blog_sidebar = array(
        'id' => 'blog_sidebar',
        'name' => 'Blog Widgets',

        'before_widget' => '<div class="widget %2$s %1$s">',
        'after_widget' => '</div>',

        'before_title' => '<h3 class="cdb-sidearea-title">',
        'after_title' => '</h3>'
    );

    register_sidebar($blog_sidebar);

    # Single Sidebar
    $single_sidebar = array(
        'id' => 'single',
        'name' => 'Post Single Sidebar',

        'before_widget' => '<div class="widget %2$s %1$s">',
        'after_widget' => '</div>',

        'before_title' => '<h3 class="cdb-sidearea-title">',
        'after_title' => '</h3>'
    );

    register_sidebar($single_sidebar);

    # Shop Sidebar
    $shop_sidebar = array(
        'id' => 'shop_sidebar',
        'name' => 'Shop Sidebar',

        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',

        'before_title' => '<h3 class="cdb-sidearea-title">',
        'after_title' => '</h3>'
    );

    register_sidebar($shop_sidebar);

    # Footer Widgets
    register_sidebar(array(
        'id' => 'footer1',
        'name' => 'Footer 1',
        'description' => 'Footer - first column',

        'before_widget' => '<div class="widget %2$s">',
        'after_widget' => '</div>',

        'before_title' => '<h4 class="cdb-widget-title">',
        'after_title' => '</h4>'
    ));

    register_sidebar(array(
        'id' => 'footer2',
        'name' => 'Footer 2',
        'description' => 'Footer - second column',

        'before_widget' => '<div class="widget %2$s">',
        'after_widget' => '</div>',

        'before_title' => '<h4 class="cdb-widget-title">',
        'after_title' => '</h4>'
    ));

    register_sidebar(array(
        'id' => 'footer3',
        'name' => 'Footer 3',
        'description' => 'Footer - third column',

        'before_widget' => '<div class="widget %2$s">',
        'after_widget' => '</div>',

        'before_title' => '<h4 class="cdb-widget-title">',
        'after_title' => '</h4>'
    ));

    register_sidebar(array(
        'id' => 'footer4',
        'name' => 'Footer 4',
        'description' => 'Footer - forth column',

        'before_widget' => '<div class="widget %2$s">',
        'after_widget' => '</div>',

        'before_title' => '<h4 class="cdb-widget-title">',
        'after_title' => '</h4>'
    ));

    register_sidebar(array(
        'id' => 'cdb-top-bar-left',
        'name' =>  'Top Bar Left',
        'descriptiopn' => 'Tob Bar - left side',
        'before_widget' => '<div id="%1$s" class="widget %2$s cdb-top-bar-widget"><div class="cdb-top-bar-widget-inner">',
        'after_widget'  => '</div></div>'
    ));

    register_sidebar(array(
        'id' => 'cdb-top-bar-right',
        'name' =>  'Top Bar Right',
        'descriptiopn' => 'Tob Bar - right side',
        'before_widget' => '<div id="%1$s" class="widget %2$s cdb-top-bar-widget"><div class="cdb-top-bar-widget-inner">',
        'after_widget'  => '</div></div>'
    ));
}

# Admin Enqueue
function codebean_admin_enqueue_scripts() {
    wp_enqueue_style('admin-css');
}

# Third party plugins
add_action('tgmpa_register', 'goseowp_plugins');
function goseowp_plugins() {
    $plugins = array(

        array(
            'name'               => esc_html__( 'Redux Framework', 'nuovowp' ),
            'slug'               => 'redux-framework',
            'required'           => true,
        ),

	    array(
		    'name'               => esc_html__( 'Portfolio Post Type', 'nuovowp' ),
		    'slug'               => 'portfolio-post-type',
		    'required'           => false,
	    ),

        array(
            'name'               => esc_html__( 'WPBakery Page Builder', 'nuovowp' ),
            'slug'               => 'js_composer',
            'source'             => get_template_directory() . '/includes/plugins/js_composer.zip',
            'required'           => false,
        ),

	    array(
		    'name'               => esc_html__( 'Revolution Slider', 'nuovowp' ),
		    'slug'               => 'revslider',
		    'source'             => get_template_directory() . '/includes/plugins/revslider.zip',
		    'required'           => false,
	    ),

        array(
	        'name'               => esc_html__( 'UberMenu', 'nuovowp' ),
	        'slug'               => 'ubermenu',
	        'source'             => get_template_directory() . '/includes/plugins/ubermenu.zip',
	        'required'           => false,
	        'version'            => '3.4.0.1',
        ),

	    array(
		    'name'               => esc_html__( 'Advanced Custom Fields PRO', 'nuovowp' ),
		    'slug'               => 'advanced-custom-fields-pro',
		    'source'             => get_theme_file_path() . '/includes/plugins/advanced-custom-fields-pro.zip',
		    'required'           => true,
	    ),

        array(
            'name'              => esc_html__( 'Contact Form 7', 'nuovowp' ),
            'slug'              => 'contact-form-7',
            'required'          => true,
        ),

        array(
            'name'               => esc_html__( 'WooCommerce', 'nuovowp' ),
            'slug'               => 'woocommerce',
            'required'           => false,
        )
    );

    $config = array(
        'default_path'    => '',
        'menu'            => 'tgmpa-install-plugins',
        'has_notices'     => true,
        'dismissable'     => true,
        'dismiss_msg'     => '',
        'is_automatic'    => false,
        'message'         => '',
    );

    tgmpa( $plugins, $config );
}






# Blog Pagination
function codebean_blog_pagination() {
    $blog_pagination_style = 'regular';
    $blog_pagination_alignment = 'center';

    if ( class_exists('Redux') ) {
        $blog_pagination_style = isset($_GET['pagination_type']) ? $_GET['pagination_type'] : codebean_option( 'blog_pagination_style', 'regular' );
        $blog_pagination_alignment = codebean_option( 'blog_pagination_alignment', 'center' );
    }

    if ($blog_pagination_style == 'regular' || is_archive()) {
    ?>
        <div class="cdb-pagination text-<?php echo esc_attr( $blog_pagination_alignment ); ?>">

            <?php echo paginate_links( array(
	            'type'      => 'list',
	            'prev_text' => '<i class="fas fa-angle-left"></i>',
	            'next_text' => '<i class="fas fa-angle-right"></i>',
            ) ); ?>

        </div>
    <?php
    } else if ($blog_pagination_style == 'load_more') {
	?>
    <div class="cdb-pagination text-<?php echo esc_attr( $blog_pagination_alignment ); ?>">
        <a href="#" class="btn btn-bordered btn-light cdb-load-more" title="<?php esc_attr_e('Load More', 'nuovowp'); ?>" data-count="<?php echo esc_attr(get_option('posts_per_page')); ?>"><?php esc_html_e('Load More', 'nuovowp'); ?></a>
    </div>
    <?php
	} else if ($blog_pagination_style == 'infinite_scroll') {
	?>
    <div class="cdb-pagination">
        <div class="cdb-preloader"><?php get_template_part( 'assets/images/preloader.svg' ); ?></div>
    </div>
    <?php
    }
}
add_action( 'codebean_blog_pagination', 'codebean_blog_pagination',3 );

# Post Navigation
function codebean_post_nav() {
    $prev = get_previous_post();
    $next = get_next_post();

    $archive_url = false;

    $portfolio_url = get_home_url();

    if ( class_exists('Redux') ) {
        $portfolio_url = codebean_option('portfolio_main_page');
    }

    if ( get_post_type() == 'post' ) {
	    $archive_page = get_option( 'page_for_posts' );
	    $archive_url = get_permalink( $archive_page );
    } elseif ( get_post_type() == 'portfolio' ) {
        $archive_page = $portfolio_url;
        $archive_url = get_permalink( $archive_page );
    }

    ?>
    <div class="cdb-post-nav">
        <div class="cdb-post-nav-btn prev-btn">
	        <?php if ($prev) { ?>
                <a href="<?php echo get_permalink($prev->ID); ?>" class="cdb-post-nav-link prev">
			        <?php get_template_part( 'assets/images/arrow-prev.svg' ); ?>
                    <span><?php esc_html_e('Newer', 'nuovowp'); ?></span>
                    <strong><?php echo esc_html($prev->post_title); ?></strong>
                </a>
	        <?php } ?>
        </div>

	    <?php if ( $archive_url ): ?>
            <div class="back-link">
                <a href="<?php echo esc_url( $archive_url ); ?>" data-toggle="tooltip" data-placement="top" title="<?php esc_attr_e( 'Back to list', 'nuovowp' ); ?>">
	                <?php get_template_part( 'assets/images/back_to_grid.svg' ); ?>
                </a>
            </div>
	    <?php endif ?>

        <div class="cdb-post-nav-btn next-btn">
            <?php if ($next) { ?>
                <a href="<?php echo get_permalink($next->ID); ?>" class="cdb-post-nav-link next">
                    <?php get_template_part( 'assets/images/arrow-next.svg' ); ?>
                    <span><?php esc_html_e('Older', 'nuovowp'); ?></span>
                    <strong><?php echo esc_attr($next->post_title); ?></strong>
                </a>
            <?php } ?>
        </div>
    </div>
    <?php

}
add_action( 'codebean_post_nav', 'codebean_post_nav', 3, 3 );

/**
 * After Content Import
 */
if ( ! function_exists( 'nuovo_after_content_import' ) ) {
    function nuovo_after_content_import( $demo_active_import , $demo_directory_path ) {

	    reset( $demo_active_import );
	    $current_key = key( $demo_active_import );

	    $locations = get_theme_mod('nav_menu_locations');
	    $menus  = wp_get_nav_menus();

	    if(!empty($menus)) {
		    foreach($menus as $menu)
		    {
			    if(is_object($menu) && $menu->name == 'Main Menu')
			    {
				    $locations['primary'] = $menu->term_id;
			    }
			    if(is_object($menu) && $menu->name == 'Mobile Menu')
			    {
				    $locations['secondary'] = $menu->term_id;
			    }
		    }
	    }

	    set_theme_mod('nav_menu_locations', $locations);

	    update_option( 'show_on_front', 'page' );

	    $front_page = get_page_by_title( 'Main Home' );
	    if ( isset( $front_page->ID ) ) {
		    update_option( 'page_on_front', $front_page->ID );
	    }

	    $blog_page = get_page_by_title( 'Blog' );
	    if ( isset( $blog_page->ID ) ) {
		    update_option( 'page_for_posts', $blog_page->ID );
	    }

	    if ( class_exists( 'RevSlider' ) ) {

		    $wbc_sliders_array = array(
			    'demo' => array('home_boxed_slider.zip', 'main_home_slider.zip', 'digital_marketing_hero.zip', 'startup_home.zip')
		    );

		    if ( isset( $demo_active_import[$current_key]['directory'] ) && !empty( $demo_active_import[$current_key]['directory'] ) && array_key_exists( $demo_active_import[$current_key]['directory'], $wbc_sliders_array ) ) {
			    $wbc_slider_import = $wbc_sliders_array[$demo_active_import[$current_key]['directory']];

			    if( is_array( $wbc_slider_import ) ){
				    foreach ($wbc_slider_import as $slider_zip) {
					    if ( !empty($slider_zip) && file_exists( $demo_directory_path.$slider_zip ) ) {
						    $slider = new RevSlider();
						    $slider->importSliderFromPost( true, true, $demo_directory_path.$slider_zip );
					    }
				    }
			    }else{
				    if ( file_exists( $demo_directory_path.$wbc_slider_import ) ) {
					    $slider = new RevSlider();
					    $slider->importSliderFromPost( true, true, $demo_directory_path.$wbc_slider_import );
				    }
			    }
		    }
	    }

    }

	add_action( 'wbc_importer_after_content_import', 'nuovo_after_content_import', 10, 2 );
}