<?php
/**
 * Nuovo WordPress Theme
 *
 * Codebean.co
 * www.codebean.co
 */

# GET/POST getter
function cdb_get( $var ) {
    return isset($_GET[$var]) ? $_GET[$var] : (isset($_REQUEST[$var]) ? $_REQUEST[$var] : '');
}

function post($var) {
    return isset($_POST[$var]) ? $_POST[$var] : null;
}

// Get element from array by key (fail safe)
function get_array_key( $arr, $key ) {
    if ( ! is_array( $arr ) ) {
        return null;
    }

    return isset( $arr[ $key ] ) ? $arr[ $key ] : null;
}

# Compress Text Function
function compress_text($buffer) {
    /* remove comments */
    $buffer = preg_replace('!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $buffer);
    /* remove tabs, spaces, newlines, etc. */
    $buffer = str_replace(array("\r\n", "\r", "\n", "\t", '	', '	', '	'), '', $buffer);
    return $buffer;
}

// Codebean Excerpt Clean
function codebean_clean_excerpt( $content, $strip_tags = false ) {
    $content = strip_shortcodes( $content );
    $content = preg_replace( '#<style.*?>(.*?)</style>#i', '', $content );
    $content = preg_replace( '#<script.*?>(.*?)</script>#i', '', $content );

    return $strip_tags ? strip_tags( $content ) : $content;
}

// Immediate Return Function
function codebean_immediate_return_fn( $return ) {
    $return_fn = 'return "' . addslashes( $return ) . '";';

    if ( is_numeric( $return ) ) {
        $return_fn = "return {$return};";
    }

    return create_function( '', $return_fn );
}

# Shop Supported
function is_shop_supported() {
    return is_array( get_option( 'active_plugins' ) ) && in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) );
}

# Print attribute values based on boolean value
function when_match( $bool, $str = '', $otherwise_str = '', $echo = true ) {
    $str = trim( $bool ? $str : $otherwise_str );

    if ( $str ) {
        $str = ' ' . $str;

        if ( $echo ) {
            echo esc_attr($str);
            return '';
        }
    }

    return $str;
}

// Get Enabled Options from Redux
function codebean_get_enabled_options( $items ) {
    $enabled = array();

    if ( isset( $items['enabled'] ) ) {
        foreach ( $items['enabled'] as $item_id => $item ) {

            if ( $item_id == 'placebo' ) {
                continue;
            }

            $enabled[ $item_id ] = $item;
        }
    }

    return $enabled;
}

// Custom Style Generator
$bottom_styles = array();

function generate_custom_style( $selector, $props = '', $media = '', $footer = false ) {
    global $bottom_styles;

    $css = '';

    // Selector Start
    $css .= $selector . ' {' . PHP_EOL;

    // Selector Properties
    $css .= str_replace( ';', ';' . PHP_EOL, $props );

    $css .= PHP_EOL . '}';
    // Selector End

    // Media Wrap
    if ( trim( $media ) ) {
        if ( strpos( $media, '@' ) == false ) {
            $css = "@media {$media} { {$css} }";
        } else {
            $css = "{$media} { {$css} }";
        }
    }

    if ( ! $footer || defined( 'DOING_AJAX' ) ) {
        echo "<style>{$css}</style>";
        return;
    }

    $bottom_styles[] = $css;
}

# Enable Support For Plugins Check in Multisite Setup
function codebean_is_plugin_active_for_network( $plugin ) {
	if ( !is_multisite() )
		return false;

	$plugins = get_site_option( 'active_sitewide_plugins');
	if ( isset($plugins[$plugin]) )
		return true;

	return false;
}

// Allow SVG Upload
if( ! function_exists( 'goseowp_allow_svg_upload' ) ) {
	add_filter( 'upload_mimes', 'goseowp_allow_svg_upload', 100, 1 );
	function goseowp_allow_svg_upload( $mimes ) {
		$mimes['svg'] = 'image/svg+xml';
		$mimes['svgz'] = 'image/svg+xml';
		return $mimes;
	}
}

# Has transparent header
function has_transparent_header() {
    return get_post_meta( get_the_ID(),'enable_transparent_header', true );
}

// Convert an english word to number
function codebean_get_number_from_word( $word ) {

    if ( is_numeric( $word ) ) {
        return $word;
    }

    switch ( $word ) {
        case 'ten' 	 : return 10; break;
        case 'nine'  : return 9; break;
        case 'eight' : return 8; break;
        case 'seven' : return 7; break;
        case 'six' 	 : return 6; break;
        case 'five'  : return 5; break;
        case 'four'	 : return 4; break;
        case 'three' : return 3; break;
        case 'two' 	 : return 2; break;
        case 'one'	 : return 1; break;
    }

    return 0;
}

// Kses Img Attribute
function codebean_kses_img($content) {
	$img_atts = apply_filters('codebean_kses_img_atts', array(
		'src'    => true,
		'alt'    => true,
		'height' => true,
		'width'  => true,
		'class'  => true,
		'id'     => true,
		'title'  => true
	));

	return wp_kses($content, array(
		'img' => $img_atts
	));
}

// Function that echoes generated style attributes
function goseowp_codebean_inline_style($value) {
    echo goseowp_codebean_get_inline_style($value);
}

// Function that generates style attribute and returns generated string
function goseowp_codebean_get_inline_style($value) {
    return goseowp_codebean_get_inline_attr($value, 'style', ';');
}

// Generate multiple inline attributes
function goseowp_codebean_get_inline_attrs($attrs) {
    $output = '';

    if(is_array($attrs) && count($attrs)) {
        foreach($attrs as $attr => $value) {
            $output .= ' '.goseowp_codebean_get_inline_attr($value, $attr);
        }
    }

    $output = ltrim($output);

    return $output;
}

// Function that echoes class attribute
function goseowp_codebean_class_attribute($value) {
    echo goseowp_codebean_get_class_attribute($value);
}

// Function that returns generated class attribute
function goseowp_codebean_get_class_attribute($value) {
    return goseowp_codebean_get_inline_attr($value, 'class', ' ');
}

// Function that generates html attribute
function goseowp_codebean_get_inline_attr($value, $attr, $glue = '') {
    if(!empty($value)) {

        if(is_array($value) && count($value)) {
            $properties = implode($glue, $value);
        } elseif($value !== '') {
            $properties = $value;
        }

        return $attr.'="'.esc_attr($properties).'"';
    }

    return '';
}

function goseowp_codebean_get_font_weight_array($first_empty = false) {
    $font_weights = array();

    if ($first_empty) {
        $font_weights[''] = '';
    }

    $font_weights['100'] = esc_html__('Thin 100', 'nuovowp');
    $font_weights['200'] = esc_html__('Extra-Light 200', 'nuovowp');
    $font_weights['300'] = esc_html__('Light 300', 'nuovowp');
    $font_weights['400'] = esc_html__('Regular 400', 'nuovowp');
    $font_weights['500'] = esc_html__('Medium 500', 'nuovowp');
    $font_weights['600'] = esc_html__('Semi-Bold 600', 'nuovowp');
    $font_weights['700'] = esc_html__('Bold 700', 'nuovowp');
    $font_weights['800'] = esc_html__('Extra-Bold 800', 'nuovowp');
    $font_weights['900'] = esc_html__('Ultra-bold 900', 'nuovowp');

    return $font_weights;
}


// Returns array of text transforms
function goseowp_codebean_get_text_transform_array($first_empty = false) {
    $text_transforms = array();

    if ($first_empty) {
        $text_transforms[''] = '';
    }

    $text_transforms['none'] = esc_html__( 'None', 'nuovowp' );
    $text_transforms['capitalize'] = esc_html__( 'Capitalize', 'nuovowp' );
    $text_transforms['uppercase'] = esc_html__( 'Uppercase', 'nuovowp' );
    $text_transforms['lowercase'] = esc_html__( 'Lowercase', 'nuovowp' );

    return $text_transforms;
}

/* Encoding */
function codebean_encode( $value ) {

	$func = 'base64' . '_encode';
	return $func( $value );

}

function codebean_decode( $value ) {

	$func = 'base64' . '_decode';
	return $func( $value );

}


if ( ! function_exists('codebean_add_short') ) {
	function codebean_add_short( $name, $call ) {
		$func = 'add' . '_shortcode';
		return $func( $name, $call );
	}
}

//Text to on line text
if( ! function_exists( 'goseowp_codebean_text2line')) {
	function goseowp_codebean_text2line( $str ) {
		return trim(preg_replace("/('|\"|\r?\n)/", '', $str));
	}
}

if( ! function_exists( 'codebean_get_config' ) ) {
	function codebean_get_config( $name ) {
		$path = get_parent_theme_file_path ('includes/codebean_' . $name . '.php');
		if( file_exists( $path ) ) {
			return include $path;
		} else {
			return array();
		}
	}
}

if ( ! function_exists('goseowp_settings_js') ) {
	function goseowp_settings_js() {

		$custom_js = '';
		$js_ready = '';

		if ( class_exists('Redux' ) ) {
			$custom_js = codebean_option( 'custom_js' );
			$js_ready = codebean_option( 'js_ready' );
		}

		ob_start();

		if( ! empty( $custom_js ) || ! empty( $js_ready ) ): ?>
			<?php if( ! empty( $custom_js ) ): ?>
				<?php echo ($custom_js); ?>
			<?php endif; ?>
			<?php if( ! empty( $js_ready ) ): ?>
				jQuery(document).ready(function() {
				<?php echo ($js_ready); ?>
				});
			<?php endif; ?>
		<?php endif;

		return ob_get_clean();
	}
}


// Display Paging Navigation
if ( !function_exists( 'codebean_paging_navigation' ) ) {
	function codebean_paging_navigation( $query_object ) {

		// Don't print empty markup if there's only one page.
		if ( $query_object->max_num_pages < 2 ) {
			return;
		}

		$paged        = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
		$pagenum_link = html_entity_decode( get_pagenum_link() );
		$query_args   = array();
		$url_parts    = explode( '?', $pagenum_link );

		if ( isset( $url_parts[1] ) ) {
			wp_parse_str( $url_parts[1], $query_args );
		}

		$pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
		$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

		$format  = $GLOBALS['wp_rewrite']->using_index_permalinks() && ! strpos( $pagenum_link, 'index.php' ) ? 'index.php/' : '';
		$format .= $GLOBALS['wp_rewrite']->using_permalinks() ? user_trailingslashit( 'page/%#%', 'paged' ) : '?paged=%#%';

		// Set up paginated links.
		$page_links = paginate_links( array(
			'base'     => $pagenum_link,
			'format'   => $format,
			'total'    => $query_object->max_num_pages,
			'current'  => $paged,
			'mid_size' => 1,
			'add_args' => array_map( 'urlencode', $query_args ),
			'type'      => 'list',
			'prev_text' => '<i class="fas fa-angle-left"></i>',
			'next_text' => '<i class="fas fa-angle-right"></i>',
		) );

		if ( $page_links ) :
			?>
            <div class="cdb-pagination text-center">

                <?php echo wp_kses_post( $page_links ); ?>

            </div>

		<?php
		endif;

	}
}

// Escape script tag
function codebean_esc_script( $str = '' ) {
    $str = str_ireplace( array( '<script', '</script>' ), array( '&lt;script', '&lt;/script&gt;' ), $str );
    return $str;
}

// Is ACF Pro Activated
function is_acf_pro_activated() {
    return is_array( get_option( 'active_plugins' ) ) && in_array( 'advanced-custom-fields-pro/acf.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) );
}

# Redux Related Functions
function codebean_remove_demo_mode_link() {
    if ( class_exists('ReduxFrameworkPlugin') ) {
        remove_filter( 'plugin_row_meta', array( ReduxFrameworkPlugin::get_instance(), 'plugin_metalinks'), null, 2 );
    }
    if ( class_exists('ReduxFrameworkPlugin') ) {
        remove_action('admin_notices', array( ReduxFrameworkPlugin::get_instance(), 'admin_notices' ) );
    }
}
add_action( 'init', 'codebean_remove_demo_mode_link');

function codebean_remove_redux_menu() {
    remove_submenu_page('tools.php','redux-about');
}
add_action( 'admin_menu', 'codebean_remove_redux_menu', 12 );