<?php
/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */

if ( ! class_exists( 'Redux' ) ) {
    return;
}

// This is your option name where all the Redux data is stored.
$opt_name = 'codebean_option';

$goseowp_codebean_selectors = codebean_get_config('selectors');

/**
 * ---> SET ARGUMENTS
 * All the possible arguments for Redux.
 * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
 * */

$theme = wp_get_theme(); // For use with some settings. Not necessary.

$codebean_social_networks_shortcode = "
<code style='font-size: 10px; display: inline-block; margin-top: 10px;'>[cdb_social_networks]</code><br>
<code style='font-size: 10px; display: inline-block; margin-top: 10px;'>[cdb_social_networks rounded]</code><br>
<code style='font-size: 10px; display: inline-block; margin-top: 10px;'>[cdb_social_networks colored]</code><br>
<code style='font-size: 10px; display: inline-block; margin-top: 10px;'>[cdb_social_networks colored=\"hover\"]</code><br>
<code style='font-size: 10px; display: inline-block; margin-top: 10px;'>[cdb_social_networks rounded colored=\"hover\"]</code><br>
<code style='font-size: 10px; display: inline-block; margin-top: 10px;'>[cdb_social_networks colored-bg]</code><br>";

function newIconFont() {
    wp_enqueue_style('icons-fontawesome');
}
add_action( 'redux/page/codebean_option/enqueue', 'newIconFont' );

$args = array(
    'opt_name'             => $opt_name,
    'display_name'         => $theme->get( 'Name' ),
    'display_version'      => $theme->get( 'Version' ),
    'menu_type'            => 'menu',
    'allow_sub_menu'       => true,
    'menu_title'           => esc_html__( 'Theme Settings', 'nuovowp' ),
    'page_title'           => esc_html__( 'Theme Settings', 'nuovowp' ),
    'google_api_key'       => '',
    'google_update_weekly' => false,
    'async_typography'     => false,
    'admin_bar'            => true,
    'admin_bar_icon'       => 'dashicons-laptop',
    'admin_bar_priority'   => 50,
    'global_variable'      => '',
    'dev_mode'             => false,
    'show_options_object'  => false,
    'update_notice'        => true,
    'customizer'           => true,
    'disable_tracking'     => true,

    // OPTIONAL -> Give you extra features
    'page_priority'        => 61,
    'page_parent'          => 'themes.php',
    'page_permissions'     => 'manage_options',
    'menu_icon'            => 'dashicons-laptop',
    'last_tab'             => '',
    'page_icon'            => 'icon-themes',
    'page_slug'            => 'theme-options',
    'save_defaults'        => true,
    'default_show'         => false,
    'default_mark'         => '',
    'show_import_export'   => true,

    // CAREFUL -> These options are for advanced use only
    'transient_time'       => 60 * MINUTE_IN_SECONDS,
    'output'               => true,
    'output_tag'           => true,
    'database'             => '',
    'use_cdn'              => true,
    // HINTS
    'hints'                => array(
        'icon'          => 'el-question-sign',
        'icon_position' => 'right',
        'icon_color'    => 'lightgray',
        'icon_size'     => 'normal',
        'tip_style'     => array(
            'color'   => 'red',
            'shadow'  => true,
            'rounded' => false,
            'style'   => '',
        ),
        'tip_position'  => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect'    => array(
            'show' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'mouseover',
            ),
            'hide' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'click mouseleave',
            ),
        ),
    )

);

Redux::setArgs( $opt_name, $args );

# End Arguments


# Start Sections


# General Settings
Redux::setSection( $opt_name, array(
    'title'             => esc_html__( 'General', 'nuovowp' ),
    'id'                => 'codebean_general',
    'desc'              => '',
    'customizer_width'  => '400px',
    'submenu'           => true,
    'icon'              => 'el-icon-home',
    'fields' => array(
	    array (
		    'id' => 'favicon',
		    'type' => 'media',
		    'desc' => esc_html__( 'Upload image: png, ico', 'nuovowp' ),
		    'operator' => 'and',
		    'title' => esc_html__( 'Favicon image', 'nuovowp' ),
	    ),
	    array (
		    'id' => 'favicon_retina',
		    'type' => 'media',
		    'desc' => esc_html__( 'Upload image: png, ico', 'nuovowp' ),
		    'operator' => 'and',
		    'title' => esc_html__( 'Favicon retina image', 'nuovowp' )
	    ),
	    array (
		    'id'       => 'page_comments',
		    'type'     => 'switch',
		    'title'    => esc_html__( 'Show comments on page', 'nuovowp' ),
		    'default'  => true
	    ),
	    array (
		    'id'       => 'google_map_api_key',
		    'type'     => 'text',
		    'title'    => esc_html__('Google map API key', 'nuovowp'),
		    'subtitle' => esc_html__('Insert your Google Maps API key here to use our Google Map VC element.', 'nuovowp')
	    ),
    )
) );

# General Layouts
Redux::setSection( $opt_name, array(
	'title'             => esc_html__( 'General Layout', 'nuovowp' ),
	'id'                => 'codebean_layout',
	'desc'              => '',
	'customizer_width'  => '400px',
	'submenu'           => true,
	'icon'              => 'el-icon-website',
	'fields'            => array(
		array (
			'id'       => 'site_width',
			'type'     => 'select',
			'title'    => esc_html__( 'Site width', 'nuovowp' ),
			'subtitle' => esc_html__( 'You can make your content wrapper boxed or full width', 'nuovowp' ),
			'options'  => array(
				'full-width' => esc_html__( 'Full width', 'nuovowp' ),
				'boxed' => esc_html__( 'Boxed', 'nuovowp' ),
				'content-full' => esc_html__( 'Content full width', 'nuovowp' ),
				'wide' => esc_html__( 'Wide (1600 px)', 'nuovowp' ),
			),
			'default' => 'full-width',
			'select2' =>array('allowClear' => false)
		),
		array (
			'id'       => 'body-background',
			'type'     => 'background',
			'title'    => esc_html__( 'Site background', 'nuovowp' ),
			'subtitle' => esc_html__( 'Set background image or color for body. Only for boxed layout', 'nuovowp' ),
			'output'   => array('body')
		),
	)
) );


# Header Settings
Redux::setSection( $opt_name, array(
	'title' => esc_html__( 'Header', 'nuovowp' ),
	'id' => 'header',
	'icon' => 'el-icon-wrench'
) );

Redux::setSection( $opt_name, array(
	'title'             => esc_html__( 'Logo', 'nuovowp' ),
	'id'                => 'codebean_site_brand',
	'desc'              => '',
	'customizer_width'  => '400px',
	'subsection'        => true,
	'fields'            => array(
		array(
			'id'        => 'logo_text',
			'title'     => esc_html__( 'Logo Text', 'nuovowp' ),
			'type'      => 'text',
			'default'   => get_bloginfo('title'),
		),
		array(
			'id'        => 'use_uploaded_logo',
			'title'     => esc_html__( 'Brand Logo', 'nuovowp' ),
			'desc'      => esc_html__( 'Use your brand logo.', 'nuovowp' ),
			'type'      => 'switch',
			'default'   => false,
		),
		array(
			'id'        => 'custom_logo_image',
			'title'     => esc_html__( 'Custom Logo', 'nuovowp' ),
			'type'      => 'media',
			'required'  => array('use_uploaded_logo', '=', '1')
		),
		array(
			'id'        => 'custom_logo_max_height',
			'title'     => esc_html__( 'Logo Image Height', 'nuovowp' ),
			'type'      => 'slider',
			"default"   => 43,
			"min"       => 1,
			"step"      => 1,
			"max"       => 60,
			'desc'      => esc_html__( 'Set maximum width for logo image in the header. In pixels', 'nuovowp' ),
			'display_value' => 'label',
			'required'  => array('use_uploaded_logo', '=', '1'),
		),
		array(
			'id'        => 'use_uploaded_logo_light',
			'title'     => esc_html__( 'Transparent Logo', 'nuovowp' ),
			'type'      => 'switch',
			'default'   => false,
			'desc'      => esc_html__( 'Only applied if you have uploaded custom logo.', 'nuovowp' ),
			'required'  => array('use_uploaded_logo', '=', '1'),
		),
		array(
			'id'        => 'custom_logo_image_light',
			'title'     => esc_html__( 'Transparent Header Logo', 'nuovowp' ),
			'type'      => 'media',
			'required'  => array('use_uploaded_logo_light', '=', '1'),
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title' => 'Top bar',
	'id' => 'header-topbar',
	'subsection' => true,
	'fields' => array(
		array(
			'id'        => 'header_top_links',
			'type'      => 'switch',
			'title'     => esc_html__( 'Top Bar', 'nuovowp' ),
			'subtitle'  => esc_html__( 'Information about the header', 'nuovowp' ),
			'default'   => true,
		),
		array(
			'id'        => 'topbar_color',
			'type'      => 'select',
			'title'     => esc_html__( 'Top bar text color', 'nuovowp' ),
			'default'   => 'light',
			'options'   => array(
				'' => esc_html__( 'Dark', 'nuovowp' ),
				'light'  => esc_html__( 'Light', 'nuovowp' )
			),
			'required'  => array('header_top_links', '=', '1'),
		),
		array(
			'id'       => 'top-bar-bg',
			'type'     => 'background',
			'title'    => esc_html__( 'Top bar background', 'nuovowp' ),
			'output'   => '.cdb-header .cdb-top-header',
			'default'  => array(
				'background-color' => '#428bca'
			),
			'required'  => array('header_top_links', '=', '1'),
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title' => esc_html__( 'Header Layout', 'nuovowp' ),
	'id' => 'header-header',
	'subsection' => true,
	'fields' => array(
		array(
			'id'       => 'header_full_width',
			'type'     => 'switch',
			'title'    => esc_html__( 'Full Width', 'nuovowp' ),
			'subtitle' => esc_html__( 'Make header full width', 'nuovowp' ),
			'default'  => false,
		),
		array(
			'id'       => 'header_sticky_menu',
			'type'     => 'switch',
			'title'    => esc_html__( 'Sticky Menu', 'nuovowp' ),
			'subtitle' => esc_html__( 'Enable/disable sticky header option', 'nuovowp' ),
			'default'  => true,
		),
		array(
			'id'        => 'header_type',
			'type'      => 'image_select',
			'title'     => esc_html__( 'Header Layout', 'nuovowp' ),
			'subtitle'  => esc_html__( 'Set your prefered layout for main header.', 'nuovowp' ),
			'default'   => '1',
			'options'   => array(
				'1' => array(
					'title' => esc_html__('Header - Menu Right', 'nuovowp' ),
					'img' => get_parent_theme_file_uri('assets/images/admin/header-menu-right.png' ),
				),
				'2' => array(
					'title' => esc_html__('Header - Menu Left', 'nuovowp' ),
					'img' => get_parent_theme_file_uri('assets/images/admin/header-menu-left.png' ),
				)
			)
		),
		array(
			'id'        => 'header_links_search_form',
			'type'      => 'switch',
			'title'     => esc_html__( 'Search', 'nuovowp' ),
			'subtitle'  => esc_html__( 'Show or hide search widget on header.', 'nuovowp' ),
			'default'   => true,
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title' => esc_html__( 'Button widget', 'nuovowp' ),
	'id' => 'header-cart',
	'subsection' => true,
	'fields' => array(
		array(
			'id'        => 'header_links_button',
			'type'      => 'switch',
			'title'     => esc_html__( 'Header Button', 'nuovowp' ),
			'subtitle'  => esc_html__( 'Show or hide button widget on header.', 'nuovowp' ),
			'default'   => true,
		),
		array(
			'id'        => 'header_link_button_mobile',
			'type'      => 'switch',
			'title'     => esc_html__( 'Header Button on Mobile', 'nuovowp' ),
			'subtitle'  => esc_html__( 'Show or hide button widget on mobile menu.', 'nuovowp' ),
			'default'   => false,
		),
		array(
			'id'        => 'header_links_button_text',
			'type'      => 'text',
			'title'     => esc_html__( 'Button Text', 'nuovowp' ),
			'subtitle'  => esc_html__( 'This text will be aplied on your header button', 'nuovowp' ),
			'default'   => esc_html__( 'Button Text', 'nuovowp' ),
			'required'  => array('header_links_button', '=', '1'),
		),
		array(
			'id'        => 'header_links_button_link',
			'type'      => 'text',
			'title'     => esc_html__( 'Button Link', 'nuovowp' ),
			'placeholder' => 'https://www.mywebsite.com/',
			'required'  => array('header_links_button', '=', '1'),
		),
		array(
			'id'        => 'header_links_button_link_targer_attr',
			'type'      => 'select',
			'title'     => esc_html__( 'Link Target', 'nuovowp' ),
			'subtitle'  => esc_html__( 'Open button link in new window or current window', 'nuovowp' ),
			'default'   => '_self',
			'options'   => array(
				'_self' => esc_html__( 'Same Window', 'nuovowp' ),
				'_blank' => esc_html__( 'New Window', 'nuovowp' ),
			),
			'select2'   => array('allowClear' => false),
			'required'  => array('header_links_button', '=', '1'),
		),
		array(
			'id'        => 'header_links_button_icon',
			'type'      => 'switch',
			'title'     => esc_html__( 'Button Icon?', 'nuovowp' ),
			'subtitle'  => esc_html__( 'Show or hide icon inside button.', 'nuovowp' ),
			'default'   => false,
			'required'  => array('header_links_button', '=', '1'),
		),
		array(
			'id'       => 'header_links_button_icon_class',
			'type'     => 'text',
			'title'    => 'Button Icon Class',
			'desc'     => esc_html__( 'Icon here are from FontAwesome 5 pack.', 'nuovowp' ),
			'placeholder' => 'Example: fas fa-angle-down',
			'default'  => '',
			'required'  => array('header_links_button_icon', '=', '1'),
		),
		array(
			'id'        => 'header_links_button_icon_position',
			'type'      => 'radio',
			'title'     => esc_html__( 'Button Icon Position', 'nuovowp' ),
			'default'   => 'left',
			'options'   => array(
				'left' => esc_html__( 'Left', 'nuovowp' ),
				'right'  => esc_html__( 'Right', 'nuovowp' )
			),
			'required'  => array('header_links_button_icon', '=', '1'),
		),
	)
) );

Redux::setSection( $opt_name, array(
    'title'             => esc_html__( 'Mobile menu', 'nuovowp' ),
    'id'                => 'codebean_mobile_menu',
    'subsection'        => true,
    'fields'            => array(
        array(
            'id'        => 'mobile_menu_footer',
            'type'      => 'editor',
            'title'     => esc_html__( 'Mobile Menu Footer', 'nuovowp' ),
            'subtitle'  => esc_html__( 'This text will be applied on your mobile menu bottom part.', 'nuovowp' ),
            'default'   => '',
        ),
        array(
            'id'        => 'mobile_menu_social',
            'type'      => 'textarea',
            'title'     => esc_html__( 'Mobile Menu Social', 'nuovowp' ),
            'subtitle'  => 'Content for the right block in the subfooter e.g<br><small> You can also add social networks in footer text, example:<br> ' . $codebean_social_networks_shortcode . '</small>',
            'default'   => '[cdb_social_networks]',
        ),
    )
) );

# Footer Settings
Redux::setSection( $opt_name, array(
    'title'             => esc_html__( 'Footer', 'nuovowp' ),
    'id'                => 'footer_settings',
    'desc'              => esc_html__( 'Every footer option is included here.', 'nuovowp' ),
    'customizer_width'  => '400px',
    'icon'              => 'el-icon-photo'
) );

Redux::setSection( $opt_name, array(
    'title'             => esc_html__( 'Footer Layout', 'nuovowp' ),
    'id'                => 'footer_layout',
    'subsection'        => true,
    'fields'            => array(
        array(
            'id'        => 'footer_visibility',
            'type'      => 'switch',
            'title'     => esc_html__( 'Footer Visibility', 'nuovowp' ),
            'subtitle'  => esc_html__( 'Show or hide footer globally', 'nuovowp' ),
            'default'   => true,
        ),
        array(
            'id'        => 'footer_fixed',
            'type'      => 'select',
            'required'  => array('footer_visibility', '=' , '1'),
            'title'     => esc_html__( 'Footer Effect', 'nuovowp' ),
            'subtitle'  => esc_html__( 'This setting will stick footer to bottom edge of window behind the wrapper.', 'nuovowp' ),
            'default'   => 'default',
            'options'   => array(
                'default' => esc_html__( 'Default', 'nuovowp' ),
                'fixed' => esc_html__( 'Fixed (No Animations)', 'nuovowp' ),
                'fixed-fade' => esc_html__( 'Fixed with Fade Animation', 'nuovowp' )
            ),
            'select2' =>array('allowClear' => false)
        ),
        array(
            'id'        => 'footer_fullwidth',
            'type'      => 'switch',
            'required'  => array('footer_visibility', '=' , '1'),
            'title'     => esc_html__( 'Full-width footer', 'nuovowp' ),
            'subtitle'  => esc_html__( 'Extend footer container to the browser edge.', 'nuovowp' ),
            'default'   => false,
        ),
        array(
            'id'        => 'footer_color',
            'type'      => 'select',
            'title'     => esc_html__( 'Footer text color', 'nuovowp' ),
            'subtitle'  => esc_html__( 'Choose your footer color scheme', 'nuovowp' ),
            'default'   => 'dark',
            'options'   => array(
                'dark' => esc_html__( 'Light', 'nuovowp' ),
                'light'  => esc_html__( 'Dark', 'nuovowp' )
            ),
            'select2' =>array('allowClear' => false)
        ),
        array(
	        'id'       => 'footer-widgets-bg',
	        'type'     => 'background',
	        'title'    => esc_html__( 'Footer background', 'nuovowp' ),
	        'output'   => '.cdb-footer .cdb-footer-widgets',
	        'default'  => array(
		        'background-color' => '#2a2e31'
	        )
        ),
        array(
            'id'        => 'footer_widgets',
            'type'      => 'switch',
            'required'  => array('footer_visibility', '=' , '1'),
            'title'     => esc_html__( 'Footer Widgets', 'nuovowp' ),
            'subtitle'  => esc_html__( 'Show or hide footer widgets', 'nuovowp' ),
            'default'   => true,
        ),
        array(
            'id'        => 'footer_columns',
            'type'      => 'image_select',
            'required'  => array('footer_widgets', '=', '1'),
            'title'     => esc_html__( 'Footer Columns', 'nuovowp' ),
            'subtitle'  => esc_html__( 'Set columns layout for footer to split widgets.', 'nuovowp' ),
            'default'   => 'fourcolumns',
            'options'   => array(
                'fourcolumns'   => array(
                    'alt'   => '4 Columns',
                    'img' => get_parent_theme_file_uri('assets/images/admin/footer-4.png' ),
                ),
                'threecolumns'  => array(
                    'alt'   => '3 Columns',
                    'img' => get_parent_theme_file_uri('assets/images/admin/footer-3.png' ),
                ),
                'twocolumns'    => array(
                    'alt'   => '2 Columns',
                    'img' => get_parent_theme_file_uri('assets/images/admin/footer-2.png' ),
                ),
                'doubleleft'    => array(
                    'alt'   => 'Double Left',
                    'img' => get_parent_theme_file_uri('assets/images/admin/footer-double-left.png'),
                ),
                'doubleright'   => array(
                    'alt'   => 'Double Right',
                    'img' => get_parent_theme_file_uri('assets/images/admin/footer-double-right.png'),
                ),
                'onecolumn'     => array(
                    'alt'   => '1 Column',
                    'img' => get_parent_theme_file_uri('assets/images/admin/footer-1.png'),
                ),
            ),
        ),
    ),
) );

Redux::setSection( $opt_name, array(
    'title'             => esc_html__( 'Bottom Bar', 'nuovowp' ),
    'id'                => 'subfooter_options',
    'subsection'        => true,
    'fields'            => array(
        array(
            'id'        => 'subfooter_visibility',
            'type'      => 'switch',
            'title'     => esc_html__( 'Sub-footer Visibility', 'nuovowp' ),
            'subtitle'  => esc_html__( 'Show or hide sub-footer globally', 'nuovowp' ),
            'default'   => true,
            'on'        => esc_html__( 'Show', 'nuovowp' ),
            'off'       => esc_html__( 'Hide', 'nuovowp' ),
        ),
	    array(
		    'id'       => 'footer-bottom-bg',
		    'type'     => 'background',
		    'title'    => esc_html__( 'Footer background', 'nuovowp' ),
		    'output'   => '.cdb-footer .cdb-subfooter',
		    'default'  => array(
			    'background-color' => '#242527'
		    ),
		    'required'  => array('subfooter_visibility', '=' , '1'),
	    ),
        array(
            'id'        => 'subfooter_text_right',
            'type'      => 'textarea',
            'required'  => array('subfooter_visibility', '=' , '1'),
            'title'     => esc_html__( 'Sub-footer Text Right', 'nuovowp' ),
            'subtitle'  => esc_html__( 'Content for the right block in the subfooter e.g. copyrights text', 'nuovowp' ),
            'default'   => "&copy; Copyright ".date('Y').'. All Rights Reserved',
        ),
        array(
            'id'        => 'subfooter_text_left',
            'type'      => 'textarea',
            'required'  => array('subfooter_visibility', '=' , '1'),
            'title'     => esc_html__( 'Sub-footer Text Left', 'nuovowp' ),
            'subtitle'  => 'Content for the right block in the subfooter e.g<br><small> You can also add social networks in footer text, example:<br> ' . $codebean_social_networks_shortcode . '</small>',
            'default'   => '[cdb_social_networks]',
        ),
    )
) );

Redux::setSection( $opt_name, array(
    'title'             => esc_html__( 'JavaScript &amp; Tracking Code', 'nuovowp' ),
    'id'                => 'js_tracking_code',
    'subsection'        => true,
    'customizer_width'  => '450px',
    'fields'            => array(
	    array (
		    'id' => 'custom_js',
		    'type' => 'ace_editor',
		    'mode' => 'javascript',
		    'title' => esc_html__('Global Custom JS', 'nuovowp'),
	    ),
	    array (
		    'id' => 'js_ready',
		    'type' => 'ace_editor',
		    'mode' => 'javascript',
		    'title' => esc_html__('On document ready', 'nuovowp'),
		    'desc' => esc_html__('Will be executed on $(document).ready()', 'nuovowp')
	    ),
    )
) );


# Typography
Redux::setSection( $opt_name, array(
	'title' => esc_html__( 'Typography', 'nuovowp' ),
	'id' => 'typography',
	'icon' => 'el-icon-fontsize',
	'fields' => array(
		array(
			'id'          => 'primary-font',
			'type'        => 'typography',
			'title'       => esc_html__( 'Primary font', 'nuovowp' ),
			'all_styles'  => true,
			'google'      => true,
			'font-backup' => true,
			'text-align'  => false,
			'letter-spacing' => true,
			'output'      => $goseowp_codebean_selectors['primary-font'],
			'units'       =>'px',
			'subtitle'    => esc_html__( 'Set you typography options for body, paragraphs.', 'nuovowp' ),
			'default'     => array(
				'font-family' => 'Rubik',
				'google'      => true,
				'font-backup' => 'Arial, Helvetica, sans-serif'
			),
			'tags'     => 'typography'
		),
		array(
			'id'          => 'heading-font',
			'type'        => 'typography',
			'title'       => esc_html__( 'Heading Font', 'nuovowp' ),
			'google'      => true,
			'font-backup' => true,
			'font-size'   => false,
			'line-height' => false,
			'text-align'  => false,
			'font-weight' => true,
			'font-style' => false,
			'letter-spacing' => true,
			'output'      => $goseowp_codebean_selectors['heading-font'],
			'units'       =>'px',
			'subtitle'    => esc_html__( 'Set you typography options for titles, post names.', 'nuovowp' ),
			'default'     => array(
				'font-family' => 'Poppins',
				'google'      => true,
				'font-backup' => "'MS Sans Serif', Geneva, sans-serif",
			),
			'tags'        => 'typography'
		),
	)
) );


# Colors
Redux::setSection( $opt_name, array(
	'title' => esc_html__( 'Styles and colors', 'nuovowp' ),
	'id' => 'colors',
	'icon' => 'el-icon-brush',
	'fields' => array(

		array(
			'id'       => 'primary-color',
			'type'     => 'color',
			'title'    => esc_html__( 'Primary Color', 'nuovowp' ),
			'subtitle' => esc_html__( 'Pick a background color for the theme buttons and other colored elements.', 'nuovowp' ),
			'validate' => 'color',
			'output'   => $goseowp_codebean_selectors['primary-color'],
			'default'  => '#428bca'
		),
		array(
			'id'   => 'buttons_info',
			'type' => 'info',
			'style' => 'info',
			'desc' => esc_html__( 'Settings for default buttons.', 'nuovowp' )
		),
		array (
			'id'       => 'btns_default_bg',
			'type'     => 'color',
			'title'    => esc_html__('Background for default buttons', 'nuovowp'),
			'output'   => $goseowp_codebean_selectors['btns-default'],
			'default' => '#f89d0e'
		),
		array(
			'id'       => 'btns_default_text',
			'type'     => 'color',
			'title'    => esc_html__('Text color', 'nuovowp'),
			'output'   => $goseowp_codebean_selectors['btns-default-text'],
			'default' => '#fff'
		),
		array(
			'id'       => 'btns_default_bg_hover',
			'type'     => 'color',
			'title'    => esc_html__('Background on hover', 'nuovowp'),
			'output'   => $goseowp_codebean_selectors['btns-default-hover'],
			'default' => '#f89d0e'
		),
		array(
			'id'       => 'btns_default_text_hover',
			'type'     => 'color',
			'title'    => esc_html__('Text color on hover', 'nuovowp'),
			'output'   => $goseowp_codebean_selectors['btns-default-text-hover'],
			'default' => '#fff'
		),
		array(
			'id'   => 'buttons_info_2',
			'type' => 'info',
			'style' => 'info',
			'desc' => esc_html__( 'Settings for primary buttons used in shop, comments, forms etc...', 'nuovowp' )
		),
		array(
			'id'       => 'btns_primary_bg',
			'type'     => 'color',
			'title'    => esc_html__('Background for primary buttons', 'nuovowp'),
			'output'   => $goseowp_codebean_selectors['btns-primary'],
			'default' => '#428bca'
		),
		array(
			'id'       => 'btns_primary_text',
			'type'     => 'color',
			'title'    => esc_html__('Text for primary buttons', 'nuovowp'),
			'output'   => $goseowp_codebean_selectors['btns-primary-text'],
			'default' => '#fff'
		),
		array(
			'id'       => 'btns_primary_hover_bg',
			'type'     => 'color',
			'title'    => esc_html__('Background for primary buttons on hover', 'nuovowp'),
			'output'   => $goseowp_codebean_selectors['btns-primary-hover'],
			'default' => '#428bca'
		),
		array(
			'id'       => 'btns_primary_text_hover',
			'type'     => 'color',
			'title'    => esc_html__('Text for primary buttons on hover', 'nuovowp'),
			'output'   => $goseowp_codebean_selectors['btns-primary-text-hover'],
			'default' => '#fff'
		),
	)
) );


# Blog Settings
Redux::setSection( $opt_name, array(
    'title'            => esc_html__( 'Blog', 'nuovowp' ),
    'id'               => 'blog_settings',
    'icon'             => 'el-icon-pencil'
) );

Redux::setSection( $opt_name, array(
    'title'            => esc_html__( 'Blog Layout', 'nuovowp' ),
    'id'               => 'blog_options',
    'subsection'       => true,
    'fields'           => array(
        array(
            'id'        => 'blog_style',
            'type'      => 'select',
            'title'     => esc_html__( 'Blog Design', 'nuovowp' ),
            'subtitle'  => esc_html__( 'Select your preferred blog template to show blog posts', 'nuovowp' ),
            'default'   => 'style3',
            'options'   => array(
                'style1' => esc_html__( 'Masonry', 'nuovowp' ),
                'style2' => esc_html__( 'Left Thumbnail', 'nuovowp' ),
                'style3' => esc_html__( 'Default', 'nuovowp' ),
            ),
        ),
        array(
            'id'        => 'blog_masonry_columns',
            'type'      => 'button_set',
            'required'  => array('blog_style', '=' , 'style1'),
            'title'     => esc_html__( 'Masonry Columns', 'nuovowp' ),
            'subtitle'  => esc_html__( 'You can change the layout of blog masonry columns here', 'nuovowp' ),
            'default' 	=> 'three-columns',
            'options' => array(
                'two-columns' => esc_html__( '2 Columns', 'nuovowp' ),
                'three-columns' => esc_html__( '3 Columns', 'nuovowp' ),
                'four-columns' => esc_html__( '4 Columns', 'nuovowp' ),
                'five-columns' => esc_html__( '5 Columns', 'nuovowp' ),
            ),
        ),
        array(
            'id'        => 'blog_sidebar_position',
            'type'      => 'select',
            'title'     => esc_html__( 'Sidebar Position', 'nuovowp' ),
            'subtitle'  => esc_html__( 'Set blog sidebar position or hide it', 'nuovowp' ),
            'default'   => 'right',
            'options'   => array(
                'right' => esc_html__( 'Show Sidebar on Right', 'nuovowp' ),
                'left' => esc_html__( 'Show Sidebar on Left', 'nuovowp' ),
                'no' => esc_html__( 'Hide Sidebar', 'nuovowp' ),
            ),
            'select2' =>array('allowClear' => false)
        ),
        array(
            'id'        => 'blog_pagination_style',
            'type'      => 'radio',
            'title'     => esc_html__( 'Pagination Type', 'nuovowp' ),
            'subtitle'  => esc_html__( 'You can choose different blog pagination styles here. The regular pagination will be used for archive pages.', 'nuovowp' ),
            'default'   => 'regular',
            'options'   => array(
                'regular' => esc_html__( 'Regular Pagination', 'nuovowp' ),
                'load_more' => esc_html__( 'Load More Button', 'nuovowp' )
            ),
        ),
        array(
            'id'        => 'blog_pagination_alignment',
            'type'      => 'button_set',
            'title'     => esc_html__( 'Pagination Alignemnt', 'nuovowp' ),
            'subtitle'  => esc_html__( 'Choose where you want to place the pagination, left, right or center.', 'nuovowp' ),
            'default'   => 'center',
            'options'   => array(
                'left'   => esc_html__( 'Left', 'nuovowp' ),
                'center' => esc_html__( 'Center', 'nuovowp' ),
                'right'  => esc_html__( 'Right', 'nuovowp' ),
            ),
        ),

    ),
) );

Redux::setSection( $opt_name, array(
    'title'            => esc_html__( 'Single Post', 'nuovowp' ),
    'id'               => 'blog_single_post',
    'subsection'       => true,
    'fields'           => array(
        array(
            'id'        => 'article_layout',
            'title'     => esc_html__( 'Article Layout', 'nuovowp' ),
            'subtitle'  => esc_html__( '', 'nuovowp' ),
            'type'      => 'select',
            'default'   => 'style1',
            'options'   => array(
                'style3' => esc_html__( 'Full Image Parallax (No post formats)', 'nuovowp' ),
                'style1' => esc_html__( 'Full Image with Sidebar (No post formats)', 'nuovowp' ),
                'style2' => esc_html__( 'Medium Image with Sidebar', 'nuovowp' ),
                'style4' => esc_html__( 'Small Image with Sidebar', 'nuovowp' ),
            )
        ),
        array(
            'id'        => 'article_author',
            'type'      => 'switch',
            'title'     => esc_html__( 'Display Author Info?', 'nuovowp' ),
            'subtitle'  => esc_html__( 'Displays author information at the bottom. Will only be displayed if the author description is filled.', 'nuovowp' ),
            'default'   => true,
        ),
        array(
            'id'        => 'blog_navigation',
            'type'      => 'switch',
            'title'     => esc_html__( 'Display Article Navigation?', 'nuovowp' ),
            'subtitle'  => esc_html__( 'Displays article navigation after post content.', 'nuovowp' ),
            'default'   => true,
        ),
    )
) );

$share_story_networks = array(
    'enabled' => array(
        'placebo'	=> 'placebo',
        'fb'   	 	=> 'Facebook',
        'tw'   	 	=> 'Twitter',
        'lin'       => 'LinkedIn',
        'tlr'       => 'Tumblr',
        'gp'       	=> 'Google Plus',
    ),
    'disabled' => array(
        'placebo'   => 'placebo',
        'pi'       	=> 'Pinterest',
        'em'       	=> 'Email',
        'vk'       	=> 'VKontakte',
    ),
);

Redux::setSection( $opt_name, array(
    'title'            => esc_html__( 'Sharing Settings', 'nuovowp' ),
    'id'               => 'sharing_settings',
    'subsection'       => true,
    'fields'           => array(
        array(
            'id'       => 'blog_share_story',
            'title'    => esc_html__( 'Share Story', 'nuovowp' ),
            'subtitle' => esc_html__( 'Enable or disable sharing blog post on social networks', 'nuovowp' ),
            'type'     => 'switch',
            'default'  => true,
            'on'       => esc_html__( 'Allow Share', 'nuovowp' ),
            'off'      => esc_html__( 'No', 'nuovowp' ),
        ),
        array(
            'id'       => 'blog_share_story_networks',
            'title'    => esc_html__( 'Share on:', 'nuovowp' ),
            'subtitle' => esc_html__( 'Choose social networks that visitors can share your blog post', 'nuovowp' ),
            'type'     => 'sorter',
            'options'  => $share_story_networks,
            'required' => array('blog_share_story', '=', '1'),
        ),
    )
) );

Redux::setSection( $opt_name, array(
    'title'            => esc_html__( 'Other Settings', 'nuovowp' ),
    'id'               => 'other_blog_settings',
    'subsection'       => true,
    'fields'           => array(
        array(
            'id'        => 'blog_show_header_title',
            'type'      => 'switch',
            'title'     => esc_html__( 'Blog Title & Description', 'nuovowp' ),
            'subtitle'  => esc_html__( 'Show header title and description in blog page.', 'nuovowp' ),
            'default'   => true,
            'on'        => 'Enable',
            'off'       => 'Disable',
        ),
        array(
            'id'        => 'blog_title',
            'type'      => 'text',
            'title'     => esc_html__( 'Blog header title (optional)', 'nuovowp' ),
            'subtitle'  => '',
            'required'  => array('blog_show_header_title', '=' , '1'),
            'default'   => 'Blog',
        ),
        array(
            'id'        => 'blog_description',
            'type'      => 'textarea',
            'title'     => esc_html__( 'Blog description in header (optional)', 'nuovowp' ),
            'subtitle'  => '',
            'required'  => array('blog_show_header_title', '=' , '1'),
            'default'   => 'Blog description comes at this place, showing photos, videos, galleries etc...',
        )
    )
) );


# Portfolio Settings
Redux::setSection( $opt_name, array(
	'title'             => esc_html__( 'Portfolio', 'nuovowp' ),
	'id'                => 'portfolio_settings',
	'icon'              => 'el-icon-th',
) );

Redux::setSection( $opt_name, array(
	'title'             => esc_html__( 'Portfolio Layout', 'nuovowp' ),
	'id'                => 'portfolio_layout',
	'subsection'        => true,
	'fields'            => array(
		array(
			'id' => 'portfolio_style',
			'type'     => 'select',
			'title'    => esc_html__('Portfolio Style', 'nuovowp'),
			'subtitle' => esc_html__('You can use different styles for your projects.', 'nuovowp'),
			'options'  => array(
				'style1' => esc_html__('Text under image', 'nuovowp'),
				'style2' => esc_html__('Show info on hover', 'nuovowp'),
			),
			'default' => 'style1',
			'select2'   => array('allowClear' => false)
		),
		array(
			'id'       => 'portfolio_full_width',
			'type'     => 'switch',
			'title'    => esc_html__('Full Width portfolio', 'nuovowp'),
			'subtitle' => esc_html__('Makes container 100% width of the page', 'nuovowp'),
			'default' => false
		),
		array(
			'id'       => 'portfolio_columns',
			'type'     => 'button_set',
			'title'    => esc_html__('Projects columns', 'nuovowp'),
			'subtitle' => esc_html__('How many projects you want to show per row', 'nuovowp'),
			'options'  => array(
				2 => '2',
				3 => '3',
				4 => '4',
				6 => '6'
			),
			'default' => 3
		),
		array(
			'id'       => 'portfolio_spacing',
			'type'     => 'button_set',
			'title'    => esc_html__('Space between projects', 'nuovowp'),
			'subtitle' => esc_html__('You can set different spacing between blocks on portfolio page', 'nuovowp'),
			'options'  => array(
				0 => '0',
				2 => '2',
				6 => '5',
				10 => '10',
				20 => '20',
				30 => '30'
			),
			'default' => 30
		),
		array(
			'id'       => 'portfolio_per_page',
			'type'     => 'text',
			'title'    => esc_html__('Items per page', 'nuovowp'),
			'default' => 12
		),
		array(
			'id'       => 'portfolio_pagination',
			'type'     => 'switch',
			'title'    => esc_html__( 'Show portfolio pagination', 'nuovowp' ),
			'default'  => true
		),
		array(
			'id'       => 'portfolio_orderby',
			'type'     => 'select',
			'title'    => esc_html__('Portfolio order by', 'nuovowp'),
			'options'  => array(
				'date' =>esc_html__( 'Date', 'nuovowp'),
				'ID' => esc_html__( 'ID', 'nuovowp'),
				'title' => esc_html__( 'Title', 'nuovowp'),
				'modified' => esc_html__( 'Modified', 'nuovowp'),
				'menu_order' => esc_html__( 'Menu order', 'nuovowp')
			),
			'default' => 'date',
			'select2'   => array('allowClear' => false)
		),
		array(
			'id'       => 'portfolio_order',
			'type'     => 'select',
			'title'    => esc_html__('Portfolio order', 'nuovowp'),
			'options'  => array(
				'DESC' =>esc_html__( 'DESC', 'nuovowp'),
				'ASC' => esc_html__( 'ASC', 'nuovowp'),
			),
			'default' => 'DESC',
			'select2'   => array('allowClear' => false)
		),
		array(
			'id'       => 'portfolio_filters',
			'type'     => 'switch',
			'title'    => esc_html__('Show categories filters', 'nuovowp'),
			'default'  => true
		),
		array(
			'id'       => 'portfolio_single_nav',
			'type'     => 'switch',
			'title'    => esc_html__('Projects navigation', 'nuovowp'),
			'subtitle' => esc_html__('Next and previous projects links on single project page', 'nuovowp'),
			'default' => true
		),
		array(
			'id'       => 'portfolio_single_related',
			'type'     => 'switch',
			'title'    => esc_html__('Related Projects', 'nuovowp'),
			'subtitle' => esc_html__('Show related projects carousel.', 'nuovowp'),
			'default' => true
		),
		array(
			'id'       => 'portfolio_main_page',
			'type'     => 'select',
			'title'    => esc_html__('Portfolio Main Page', 'nuovowp'),
			'data'     => 'pages',
		),
	)
) );

Redux::setSection( $opt_name, array(
	'title'             => esc_html__( 'Sharing Settings', 'nuovowp' ),
	'id'                => 'portfolio_sharing',
	'subsection'        => true,
	'fields'            => array(
		array(
			'id'       => 'portfolio_share_story',
			'title'    => esc_html__( 'Share Story', 'nuovowp' ),
			'subtitle' => esc_html__( 'Enable or disable sharing portfolio item on social networks', 'nuovowp' ),
			'type'     => 'switch',
			'default'  => true,
			'on'       => esc_html__( 'Allow Share', 'nuovowp' ),
			'off'      => esc_html__( 'No', 'nuovowp' ),
		),
		array(
			'id'       => 'portfolio_share_story_networks',
			'title'    => esc_html__( 'Share on:', 'nuovowp' ),
			'subtitle' => esc_html__( 'Choose social networks that visitors can share your portfolio item', 'nuovowp' ),
			'type'     => 'sorter',
			'options'  => $share_story_networks,
			'required' => array('blog_share_story', '=', '1'),
		)
	)
) );

# Shop Settings
Redux::setSection( $opt_name, array(
    'title'            => esc_html__( 'Shop', 'nuovowp' ),
    'id'               => 'shop_settings',
    'desc'             => esc_html__( 'These are really basic fields!', 'nuovowp' ),
    'customizer_width' => '400px',
    'icon'             => 'fas fa-shopping-cart'
) );


$shop_sidebar_options = array(
    'hide' => esc_html__( 'Hide Sidebar', 'nuovowp' ),
    'right' => esc_html__( 'Show Sidebar on Right', 'nuovowp' ),
    'left' => esc_html__( 'Show Sidebar on Left', 'nuovowp' ),
);

Redux::setSection( $opt_name, array(
    'title'            => esc_html__( 'Shop Options', 'nuovowp' ),
    'id'               => 'shop_options',
    'subsection'       => true,
    'fields'           => array(
        array(
            'id'       => 'shop_title_show',
            'type'     => 'checkbox',
            'title'    => esc_html__( 'Shop Heading Title', 'nuovowp' ),
            'default'  => true,
        ),
        array(
            'id'       => 'shop_sorting_show',
            'type'     => 'checkbox',
            'title'    => esc_html__( 'Product Sorting &amp; Results Count', 'nuovowp' ),
            'default'  => true,
        ),
        array(
            'id'       => 'shop_product_price_listing',
            'type'     => 'checkbox',
            'title'    => esc_html__( 'Show item price', 'nuovowp' ),
            'default'  => '1',
        ),
        array(
            'id'       => 'shop_add_to_cart_listing',
            'type'     => 'checkbox',
            'title'    => esc_html__( 'Add to cart product', 'nuovowp' ),
            'default'  => '1',
        ),
        array(
            'id'       => 'shop_product_category_listing',
            'type'     => 'checkbox',
            'title'    => esc_html__( 'Show item category', 'nuovowp' ),
            'default'  => '1',
        ),
        array(
            'id'       => 'products_masonry',
            'type'     => 'checkbox',
            'title'    => esc_html__('Masonry grid', 'nuovowp'),
            'subtitle' => esc_html__('Products may have different sizes', 'nuovowp'),
            'default' => false
        ),
        array(
            'id'       => 'shop_sidebar',
            'type'     => 'select',
            'title'    => esc_html__( 'Shop Sidebar', 'nuovowp' ),
            'subtitle' => esc_html__( 'Shop sidebar position', 'nuovowp' ),
            'default'  => 'right',
            'options'  => $shop_sidebar_options,
            'select2'  => array('allowClear' => false)
        ),
        array(
            'id'       => 'products_columns',
            'type'     => 'select',
            'title'    => esc_html__('Products columns', 'nuovowp'),
            'subtitle' => esc_html__('How many products you want to show per row', 'nuovowp'),
            'options'  => array(
                2 => '2',
                3 => '3',
                4 => '4',
                6 => '6'
            ),
            'default' => 4,
            'select2'  => array('allowClear' => false),
        ),
        array(
            'id'       => 'shop_per_page',
            'type'     => 'spinner',
            'title'    => esc_html__( 'Products per page', 'nuovowp' ),
            'subtitle' => esc_html__( 'Number of products per page', 'nuovowp' ),
            'default'  => '12',
            'min'      => '1',
            'max'      => '20',
        ),
    )
) );

Redux::setSection( $opt_name, array(
    'title'            => esc_html__( 'My Account', 'nuovowp' ),
    'id'               => 'myaccount_options',
    'subsection'       => true,
    'customizer_width' => '450px',
    'fields'           => array(
        array(
            'id'		=> 'myaccount_profile_image',
            'type'		=> 'switch',
            'title'		=> esc_html__( 'Profile Image', 'nuovowp' ),
            'desc'		=> 'Display <a href="http://en.gravatar.com/" target="_blank">gravatar</a> profile image.',
            'default'	=> 0,
            'on'		=> 'Enable',
            'off'		=> 'Disable'
        ),
        array(
            'id' 		=> 'myaccount_dashboard_text',
            'type' 		=> 'editor',
            'title' 	=> esc_html__( 'Dashboard Text', 'nuovowp' ),
            'desc' 		=> esc_html__( 'Enter text to display on the Dashboard page.', 'nuovowp' ),
            'default'	=> '',
            'args'		=> array(
                'wpautop'	=> false,
                'teeny' 	=> true
            )
        )
    )
) );

$share_product_networks = array(
    'enabled' => array(
        'placebo'	=> 'placebo',
        'fb'   	 	=> 'Facebook',
        'tw'   	 	=> 'Twitter',
        'lin'       => 'LinkedIn',
        'tlr'       => 'Tumblr',
        'gp'       	=> 'Google Plus',
    ),
    'disabled' => array(
        'placebo'   => 'placebo',
        'pi'       	=> 'Pinterest',
        'em'       	=> 'Email',
        'vk'       	=> 'VKontakte',
    ),
);

Redux::setSection( $opt_name, array(
    'title'            => esc_html__( 'Sharing Settings', 'nuovowp' ),
    'id'               => 'shop_sharing_options',
    'subsection'       => true,
    'customizer_width' => '450px',
    'fields'           => array(
        array(
            'id'       => 'shop_share_product',
            'title'    => esc_html__( 'Share Product', 'nuovowp' ),
            'subtitle' => esc_html__( 'Enable or disable sharing product on social networks.', 'nuovowp' ),
            'type'     => 'switch',
            'default'  => true,
            'on'       => esc_html__( 'Allow Share', 'nuovowp' ),
            'off'      => esc_html__( 'No', 'nuovowp' ),
        ),
        array(
            'id'       => 'shop_share_product_icons',
            'title'    => esc_html__( 'Share on:', 'nuovowp' ),
            'subtitle' => esc_html__( 'Choose social networks that visitors can share your product.', 'nuovowp' ),
            'type'     => 'sorter',
            'options'  => $share_story_networks,
            'required' => array('shop_share_product', '=', '1'),
        ),
    ),
) );

# Social Media Links
$social_networks_ordering = array(
    'enabled' => array (
        'placebo'	=> 'placebo',
        'fb'   	 	=> 'Facebook',
        'tw'   	 	=> 'Twitter',
        'ig'        => 'Instagram',
        'vm'        => 'Vimeo',
        'be'        => 'Behance',
    ),
    'disabled' => array (
        'placebo'   => 'placebo',
        'gp'        => "Google+",
        'lin'       => 'LinkedIn',
        'yt'        => 'YouTube',
        'drb'       => 'Dribbble',
        'pi'        => 'Pinterest',
        'vk'        => 'VKontakte',
        'da'        => 'DeviantArt',
        'fl'        => 'Flickr',
        'vi'        => 'Vine',
        'tu'        => 'Tumblr',
        'sk'        => 'Skype',
        'fs'        => 'Foursquare',
        'gh'        => 'GitHub',
        'hz'        => 'Houzz',
        'px'        => '500px',
        'xi'        => 'Xing',
        'sn'        => 'Snapchat',
        'em'        => 'Email',
        'yp'        => 'Yelp',
        'ta'        => 'TripAdvisor',
        'custom'    => 'Custom Link',
    ),
);

Redux::setSection( $opt_name, array(
    'title'             => esc_html__( 'Social Networks', 'nuovowp' ),
    'id'                => 'social_networks',
    'desc'              => '',
    'customizer_width'  => '400px',
    'submenu'           => true,
    'icon'              => 'fas fa-share-alt',
    'fields'            => array(
        // Social Networks Ordering
        array(
            'id'        => 'social_order',
            'type'      => 'sorter',
            'title'     => esc_html__( 'Social Networks Ordering', 'nuovowp' ),
            'subtitle'  => "Set the appearing order of social networks in the footer. To use social networks links list copy this shortcode:<br><br> " . $codebean_social_networks_shortcode,
            'options'   => $social_networks_ordering,
        ),
        array(
            'id'        => 'social_networks_target_attr',
            'type'      => 'select',
            'title'     => esc_html__( 'Link Target', 'nuovowp' ),
            'subtitle'  => esc_html__( 'Open social links in new window or current window', 'nuovowp' ),
            'default'   => '_blank',
            'options'   => array(
                '_self' => esc_html__( 'Same Window', 'nuovowp' ),
                '_blank' => esc_html__( 'New Window', 'nuovowp' ),
            ),
            'select2'   => array('allowClear' => false)
        ),
        array(
            'id'       => 'social_network_link_fb',
            'type'     => 'text',
            'title'    => 'Facebook',
            'placeholder' => 'https://facebook.com/username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_tw',
            'type'     => 'text',
            'title'    => 'Twitter',
            'placeholder' => 'https://twitter.com/username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_lin',
            'type'     => 'text',
            'title'    => 'Linkedin',
            'placeholder' => 'https://linkedin.com/in/username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_yt',
            'type'     => 'text',
            'title'    => 'YouTube',
            'placeholder' => 'https://youtube.com/user/username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_vm',
            'type'     => 'text',
            'title'    => 'Vimeo',
            'placeholder' => 'https://vimeo.com/username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_drb',
            'type'     => 'text',
            'title'    => 'Dribbble',
            'placeholder' => 'https://dribbble.com/username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_ig',
            'type'     => 'text',
            'title'    => 'Instagram',
            'placeholder' => 'https://instagram.com/username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_pi',
            'type'     => 'text',
            'title'    => 'Pinterest',
            'placeholder' => 'https://pinterest.com/username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_gp',
            'type'     => 'text',
            'title'    => 'Google Plus',
            'placeholder' => 'https://plus.google.com/username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_vk',
            'type'     => 'text',
            'title'    => 'VKontakte',
            'placeholder' => 'https://vk.com/username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_da',
            'type'     => 'text',
            'title'    => 'DeviantArt',
            'placeholder' => 'https://username.deviantart.com/',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_tu',
            'type'     => 'text',
            'title'    => 'Tumblr',
            'placeholder' => 'https://username.tumblr.com/',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_vi',
            'type'     => 'text',
            'title'    => 'Vine',
            'placeholder' => 'https://vine.com/username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_be',
            'type'     => 'text',
            'title'    => 'Behance',
            'placeholder' => 'https://behance.com/username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_fl',
            'type'     => 'text',
            'title'    => 'Flickr',
            'placeholder' => 'https://flickr.com/photos/username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_fs',
            'type'     => 'text',
            'title'    => 'Foursquare',
            'placeholder' => 'https://foursquare.com/username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_sk',
            'type'     => 'text',
            'title'    => 'Skype',
            'placeholder' => 'skype:username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_gh',
            'type'     => 'text',
            'title'    => 'GitHub',
            'placeholder' => 'https://github.com/username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_hz',
            'type'     => 'text',
            'title'    => 'Houzz',
            'placeholder' => 'https://houzz.com/user/username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_px',
            'type'     => 'text',
            'title'    => '500px',
            'placeholder' => 'https://500px.com/username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_vi',
            'type'     => 'text',
            'title'    => 'Xing',
            'placeholder' => 'https://xing.com/profile/username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_sn',
            'type'     => 'text',
            'title'    => 'Snapchat',
            'placeholder' => 'https://snapchat.com/add/username',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_yp',
            'type'     => 'text',
            'title'    => 'Yelp',
            'placeholder' => 'https://yelp.com/biz/alias',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_ta',
            'type'     => 'text',
            'title'    => 'Trip Advisor',
            'placeholder' => 'https://tripadvisor.com',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_em',
            'type'     => 'text',
            'title'    => 'Contact Email',
            'placeholder' => 'john.doe@email.com',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_link_em_subject',
            'type'     => 'text',
            'title'    => 'Contact Subject',
            'placeholder' => 'Hello!',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_custom_link_title',
            'type'     => 'text',
            'title'    => 'Custom Link',
            'placeholder' => 'Custom Link Title',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_custom_link_link',
            'type'     => 'text',
            'title'    => 'Link',
            'placeholder' => 'https://www.mywebsite.com/',
            'default'  => '',
        ),
        array(
            'id'       => 'social_network_custom_link_icon',
            'type'     => 'text',
            'title'    => 'Custom Link Icon',
            'desc'     => 'Icon (optional)<br><small>Note: If you want to set custom icon, enter icon alias from <a href="http://fontawesome.io/icons/" target="_blank">Font Awesome</a> icon collection.</small>',
            'placeholder' => 'Example: bookmark',
            'default'  => '',
        ),

    )
) );

Redux::setSection( $opt_name, array(
	'title'             => esc_html__( 'Other Settings', 'nuovowp' ),
	'id'                => 'other_settings',
//	'subsection'        => true,
	'icon'              => 'fas fa-cogs',
	'fields'            => array(
		array(
			'id'        => 'search_thumbnails',
			'type'      => 'switch',
			'title'     => esc_html__( 'Thumbnails for Results', 'nuovowp' ),
			'subtitle'  => esc_html__( 'Show or hide thumbnails on search results.', 'nuovowp' ),
			'default'   => '0',
		),
		array(
			'id'        => 'page_transition',
			'type'      => 'switch',
			'title'     => esc_html__( 'Page Transition', 'nuovowp' ),
			'subtitle'  => esc_html__( 'If enabled, there will be added a smooth page transition.', 'nuovowp' ),
			'default'   => '1',
		),
		array(
			'id'        => 'gotop_button',
			'type'      => 'switch',
			'required'  => array('subfooter_visibility', '=', '1'),
			'title'     => esc_html__( 'Go Top Button', 'nuovowp' ),
			'subtitle'  => esc_html__( 'Show or hide go top button.', 'nuovowp' ),
			'default'   => true,
			'on'        => esc_html__( 'Show', 'nuovowp' ),
			'off'       => esc_html__( 'Hide', 'nuovowp' ),
		)
	)
) );





# End Sections

// Function used to retrieve theme option values
if ( ! function_exists( 'codebean_option' ) ) {
    function codebean_option( $id, $fallback = false, $param = false ) {
        global $codebean_option;
        if ( $fallback == false ) $fallback = '';
        $output = ( isset( $codebean_option[$id] ) && $codebean_option[$id] !== '' ) ? $codebean_option[$id] : $fallback;
        if ( !empty( $codebean_option[$id] ) && $param ) {
            $output = $codebean_option[$id][$param];
        }
        return $output;
    }
}
