<?php
/**
 * Nuovo WordPress Theme
 *
 * Codebean.co
 * www.codebean.co
 */
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Direct access not allowed.
}

global $cdb_globals;

if ( ! is_shop_supported() ) {
    return;
}

add_theme_support( 'wc-product-gallery-zoom' );
add_theme_support( 'wc-product-gallery-lightbox' );

// Remove WooCommerce Styles
add_filter( 'woocommerce_enqueue_styles', '__return_empty_array' );

// Remove certain actions from shop archive
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20 );

remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );
remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30 );

remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10 );

remove_action( 'woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_title', 10 );

remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );

remove_action('woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5);
remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10 );

// Remove Link from Products
remove_action( 'woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10 );
remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );


// Site wide store notice
remove_action( 'wp_footer', 'woocommerce_demo_store' );
add_action( 'goseowp_before_header', 'woocommerce_demo_store', 10 );

// Reset WooCommerce loop before entering products loop
add_action( 'woocommerce_before_shop_loop', 'woocommerce_reset_loop' );



// Set image dimensions on theme activation
function goseowp_woocommerce_set_image_dimensions() {
    if ( ! get_option( 'goseowp_shop_image_sizes_set' ) ) {
        $catalog = array(
            'width' 	=> '600',	// px
            'height'	=> '600',		// px
            'crop'		=> 0 		// no-crop
        );

        $single = array(
            'width' 	=> '1200',	// px
            'height'	=> '1200',		// px
            'crop'		=> 0 		// no-crop
        );

        $thumbnail = array(
            'width' 	=> '280',		// px
            'height'	=> '280',	// px
            'crop'		=> 0 		// no-crop
        );

        // Image sizes
        update_option( 'shop_catalog_image_size', $catalog ); 		// Product category thumbs
        update_option( 'shop_single_image_size', $single ); 		// Single product image
        update_option( 'shop_thumbnail_image_size', $thumbnail ); 	// Image gallery thumbs

        // Set "images size set" option
        add_option( 'goseowp_shop_image_sizes_set', '1' );
    }
}
// Theme activation hook
add_action( 'after_switch_theme', 'goseowp_woocommerce_set_image_dimensions', 1 );

// Additional hook for when WooCommerce is installed/activated after the theme
add_action( 'admin_init', 'goseowp_woocommerce_set_image_dimensions', 1000 );





// Shop Category Item
function goseowp_shop_loop_category_thumbnail( $category ) {

	$thumbnail_id = get_term_meta( $category->term_id, 'thumbnail_id', true  );
	$thumbnail_url = wc_placeholder_img_src();

	if($thumbnail_id)
	{
		$thumbnail_url_custom = wp_get_attachment_image_src( $thumbnail_id, apply_filters('goseowp_wc_category_thumbnail_size', 'shop-category-thumb') );

		if($thumbnail_url_custom)
			$thumbnail_url = $thumbnail_url_custom[0];
	}

	echo '<img src="'.$thumbnail_url.'" alt="' . esc_attr( $category->name ) . '" />';
}

remove_action( 'woocommerce_before_subcategory_title', 'woocommerce_subcategory_thumbnail', 10 );
add_action( 'woocommerce_before_subcategory_title', 'goseowp_shop_loop_category_thumbnail' );

// Shop Category Title
function goseowp_shop_loop_category_title( $category ) {
    ?>
        <div class="product-category-heading">

            <h3 class="cat_name">
                <?php

                    echo esc_html( $category->name );
                    echo apply_filters( 'woocommerce_subcategory_count_html', ' <span class="count">(' . $category->count . ')</span>', $category );
                ?>
            </h3>

            <?php
                if ( $category->description != '' ) {
                    echo '<span class="product-category-desc">' . esc_html($category->description) . '</span>';
                }
            ?>

        </div>
    <?php
}

remove_action( 'woocommerce_shop_loop_subcategory_title', 'woocommerce_template_loop_category_title', 10 );
add_action( 'woocommerce_shop_loop_subcategory_title', 'goseowp_shop_loop_category_title' );

// Shop Products per Page
function goseowp_shop_products_per_page() {

    $shop_per_page = '12';

    if ( class_exists('Redux') ) {
        $shop_per_page = codebean_option('shop_per_page');
    }

    $per_page = 12;
    $number = apply_filters('goseowp_shop_per_page', $shop_per_page );
    if( is_numeric( $number )  &&  $number > 0) {
        $per_page = $number;
    }

    return $per_page;
}

add_filter( 'loop_shop_per_page', 'goseowp_shop_products_per_page', 20 );


// Shop Loop Image
function goseowp_template_loop_product_thumbnail() {
    echo goseowp_get_product_thumbnail();
}

function goseowp_get_product_thumbnail( $size = 'shop_catalog', $attach_id = false ) {
    global $post, $goseowp_loop;
    $custom_size = $size;
    $defined_sizes = array('shop_catalog', 'shop_catalog_x2');

    if( ! empty( $goseowp_loop['double_size'] ) && $goseowp_loop['double_size'] ) {
        $size = 'shop_catalog_x2';
    }

    if ( has_post_thumbnail() ) {

        if( ! $attach_id ) $attach_id = get_post_thumbnail_id();

        $props = wc_get_product_attachment_props( $attach_id, $post );

        if( ! empty( $goseowp_loop['img_size'] ) ) {
            $custom_size = $goseowp_loop['img_size'];
        }

        if( ! in_array( $custom_size, $defined_sizes ) && function_exists( 'wpb_getImageBySize' ) ) {

            $img = wpb_getImageBySize( array( 'attach_id' => $attach_id, 'thumb_size' => $custom_size, 'class' => 'content-product-image' ) );
            $img = $img['thumbnail'];

        } else {
            $img = wp_get_attachment_image( $attach_id, $size, array(
                'title'	 => $props['title'],
                'alt'    => $props['alt'],
            ) );
        }

        return $img;

    } elseif ( wc_placeholder_img_src() ) {
        return wc_placeholder_img( $size );
    }
}

add_action( 'woocommerce_before_shop_loop_item_title', 'goseowp_template_loop_product_thumbnail', 10 );


function goseowp_woocommerce_product_loop_item_info() {
    global $woocommerce, $product, $post;

    $cart_url = wc_get_page_permalink( 'cart' );
	$show_price = '1';

	if ( class_exists('Redux') ) {
	    $show_price = codebean_option( 'shop_product_price_listing' );
	}

    // Product URL
	$product_url = apply_filters( 'goseowp_woocommerce_loop_product_link', get_permalink( $post ), $product );
	$link_new_tab = apply_filters( 'goseowp_woocommerce_loop_product_link_new_tab', false, $product );
	?>
	<div class="product-info-holder">
        <div class="name-holder">
            <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
        </div>

        <?php
            /**
             * Filters after product title on loop view
             */
            do_action( 'goseowp_woocommerce_product_loop_after_title' );
        ?>

        <?php woocommerce_template_loop_rating(); ?>

        <?php if ( $show_price ) : ?>
            <?php woocommerce_template_loop_price(); ?>
        <?php endif; ?>

        <?php woocommerce_template_loop_add_to_cart(); ?>

    </div>
	<?php
}

add_action( 'woocommerce_after_shop_loop_item', 'goseowp_woocommerce_product_loop_item_info', 25 );


// GOSEOWP Shop Translations
function goseowp_woocmmerce_get_i18n_str( $str_id, $echo = false ) {

	$found_string = 'goseowp_woocmmerce_get_i18n_str::notFoundString';

	$strings = array(
		'Login'                                               => esc_html__( 'Login', 'nuovowp' ),
		'&laquo; Go back'                                     => esc_html__( '&laquo; Go back', 'nuovowp' ),
		'Payment Method'                                      => esc_html__( 'Payment method', 'nuovowp' ),
		'Added to cart'                                       => esc_html__( 'Added to cart', 'nuovowp' ),
		'Out of stock'                                        => esc_html__( 'Out of stock', 'nuovowp' ),
		'Hot'                                                 => esc_html__( 'Hot', 'nuovowp' ),
		'Edit information for this address type'              => esc_html__( 'Edit information for this address type', 'nuovowp' ),
		'Reset Password'                                      => esc_html__( 'Reset password', 'nuovowp' ),
		'Lost Password'                                       => esc_html__( 'Lost password', 'nuovowp' ),
		'Login or Register'                                   => esc_html__( 'Login or register', 'nuovowp' ),
		'Manage your account and see your orders'             => esc_html__( 'Manage your account and see your orders', 'nuovowp' ),
		'Go'                                                  => esc_html_x( 'Go', 'submit button', 'nuovowp' ),
		'My Account'                                          => esc_html__( 'My account', 'nuovowp' ),
		'Edit your account details or change your password'   => esc_html__( 'Edit your account details or change your password', 'nuovowp' ),
		'Password Change'                                     => esc_html__( 'Password change', 'nuovowp' ),
		'(leave blank to leave unchanged)'                    => esc_html__( '(leave blank to leave unchanged)', 'nuovowp' ),
		'Current Password'                                    => esc_html__( 'Current password', 'nuovowp' ),
		'New Password'                                        => esc_html__( 'New password', 'nuovowp' ),
	);

	if ( isset( $strings[ $str_id ] ) ) {
		$found_string = $strings[ $str_id ];
	}

	if ( ! $echo ) {
		return $found_string;
	}

	echo wp_kses_allowed_html( $found_string );
}



// Shop Sidebar
function goseowp_woocommerce_shop_products_container_before() {

    $shop_sidebar = isset($_GET['shop_sidebar']) ? $_GET['shop_sidebar'] : 'right';

    if ( class_exists('Redux') ) {
        $shop_sidebar = isset($_GET['shop_sidebar']) ? $_GET['shop_sidebar'] : codebean_option( 'shop_sidebar', 'hide' );
    }

    ?>

    <div class="row page-padding cdb-shop-holder<?php echo esc_attr( $shop_sidebar != 'hide' ? ' cdb-shop-sidebar-on' : '' ); ?>">
    <?php

    switch ($shop_sidebar) {
        case 'left':
        case 'right':
            ?>
            <div class="col-md-9<?php echo esc_attr( $shop_sidebar == 'left' ? ' pull-right-md' : '' ); ?>">
            <?php
            break;

        case 'hide' :
        default:
            ?>
            <div class="col-md-12">
            <?php
    }
}

function goseowp_woocommerce_shop_products_container_after() {

    $shop_sidebar = isset($_GET['shop_sidebar']) ? $_GET['shop_sidebar'] : 'right';

    if ( class_exists('Redux') ) {
        $shop_sidebar = isset($_GET['shop_sidebar']) ? $_GET['shop_sidebar'] : codebean_option( 'shop_sidebar', 'hide' );
    }
    ?>
        </div>

    <?php if ( $shop_sidebar != 'hide' ) : ?>
        <div class="col-md-3">
            <div class="cdb-sidebar cdb-shop-sidebar-<?php echo esc_attr( $shop_sidebar ); ?>">
                <div class="cdb-sidebar-inner">

                    <?php dynamic_sidebar( 'shop_sidebar' ); ?>

                </div>
            </div>
        </div>
    <?php endif; ?>

    </div>
    <?php
}

add_action( 'woocommerce_before_shop_loop', 'goseowp_woocommerce_shop_products_container_before' );
add_action( 'woocommerce_after_shop_loop', 'goseowp_woocommerce_shop_products_container_after' );


// Get Bootstrap Classes
function goseowp_get_grid_el_class($loop = 0, $columns = 4, $xs_size = false, $sm_size = 4, $md_size = 3) {
    $classes = '';

    if( ! in_array( $columns, array(1,2,3,4,6,12) ) ) {
        $columns = 4;
    }

    if( ! $xs_size ) {
        $xs_size = apply_filters('goseowp_grid_xs_default', 6);
    }

    if( $columns < 3) {
        $xs_size = 12;
        if($columns == 1)
            $sm_size = 12;
        else
            $sm_size = 6;
    }

    $col = ' col-xs-' . $xs_size . ' col-sm-' . $sm_size . ' col-md-';

    $md_size = 12/$columns;

    $classes .= $col . $md_size;

    if($loop > 0) {
        if ( 0 == ( $loop - 1 ) % $columns || 1 == $columns )
            $classes .= ' first ';
        if ( 0 == $loop % $columns )
            $classes .= ' last ';
    }

    return $classes;
}


// Single product: Tabs - Change "Reviews" tab title
function goseowp_woocommerce_reviews_tab_title( $title ) {
    $title = strtr( $title, array(
        '(' => '<span>',
        ')' => '</span>'
    ) );

    return $title;
}
add_filter( 'woocommerce_product_reviews_tab_title', 'goseowp_woocommerce_reviews_tab_title' );


// Share Product
function goseowp_woocommerce_share_product() {
    global $product;

    $show_share_product = '0';

    if ( class_exists('Redux') ) {
        $show_share_product = codebean_option('shop_share_product');
    }

    if ( $show_share_product ) {
	?>
	<div class="product-sharing cdb-post-share">
		<span class="share-title"><?php esc_html_e( 'Share this product:', 'nuovowp' ); ?></span>

		<ul class="cdb-social-links rounded colored-bg">
		<?php

			$share_product_networks = codebean_option( 'shop_share_product_icons' );

			if ( is_array( $share_product_networks ) ) :

				foreach ( $share_product_networks['enabled'] as $network_id => $network ) :

					if ( 'placebo' == $network_id ) {
						continue;
					}

					share_story_network_link( $network_id, $product->get_id(), '', true );

				endforeach;

			endif;

		?>
		</ul>
	</div>
	<?php }
}

add_action( 'woocommerce_single_product_summary', 'goseowp_woocommerce_share_product', 50 );


// Render Star Rating
function goseowp_woocommerce_show_rating( $average ) {

    for ( $i = 1; $i <= 5; $i++ ) :
    ?>

    <i class="fas fa-star<?php echo round( $average ) >= $i ? ' filled' : ''; ?>"></i>

    <?php
    endfor;
}

// Product rating
function goseowp_woocommerce_single_product_rating_stars() {
	global $product;

	$average = $product->get_average_rating();

	?>
	<div class="star-rating" title="<?php printf( esc_html__( 'Rated %s out of 5', 'nuovowp' ), $average ); ?>">
		<?php goseowp_woocommerce_show_rating( $average ); ?>
	</div>
	<?php
}

add_action( 'goseowp_woocommerce_single_product_rating_stars', 'goseowp_woocommerce_single_product_rating_stars', 10 );

// Review rating
function goseowp_woocommerce_product_get_rating_html( $html, $rating, $count ) {

	ob_start();
	?>
	<div class="star-rating">
		<?php
			goseowp_woocommerce_show_rating( $rating );
		?>
	</div>
	<?php

	return ob_get_clean();
}

add_action( 'woocommerce_product_get_rating_html', 'goseowp_woocommerce_product_get_rating_html', 10, 3 );

// Default Form Fields Args
function goseowp_woocommerce_form_field_args( $field ) {
    $field['class'][] = 'form-group';
    $field['input_class'] = array( 'form-control' );
    $field['placeholder'] = (isset($field['label']) ? $field['label'] : '') . (isset($field['required']) && $field['required'] ? ' *' : '');
    $field['label_class'] = 'hidden';

    if ( 'order_comments' == $field['id'] ) {
        $field['label_class'] = '';
        $field['placeholder'] = esc_attr('Include custom requirements for this order here', 'nuovowp');
        $field['input_class'] = array('form-control');
    }

    return $field;
}

add_filter( 'woocommerce_form_field_args', 'goseowp_woocommerce_form_field_args' );